@@ -27,7 +27,7 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 __title__ = 'Apprise'
-__version__ = '1.8.0'
+__version__ = '1.8.1'
 __author__ = 'Chris Caron'
 __license__ = 'BSD'
 __copywrite__ = 'Copyright (C) 2024 Chris Caron <lead2gold@gmail.com>'
@@ -60,7 +60,9 @@ from .locale import AppriseLocale
 from .asset import AppriseAsset
 from .apprise_config import AppriseConfig
 from .apprise_attachment import AppriseAttachment
-
+from .manager_attachment import AttachmentManager
+from .manager_config import ConfigurationManager
+from .manager_plugins import NotificationManager
 from . import decorators
 
 # Inherit our logging with our additional entries added to it
@@ -84,6 +86,9 @@ __all__ = [
     'ContentLocation', 'CONTENT_LOCATIONS',
     'PrivacyMode',
 
+    # Managers
+    'NotificationManager', 'ConfigurationManager', 'AttachmentManager',
+
     # Decorator
     'decorators',
 
