@@ -25,13 +25,15 @@
 # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
-
+import copy
 import re
 import sys
 import json
 import contextlib
 import os
 import locale
+import typing
+import base64
 from itertools import chain
 from os.path import expanduser
 from functools import reduce
@@ -174,6 +176,11 @@ IS_PHONE_NO = re.compile(r'^\+?(?P<phone>[0-9\s)(+-]+)\s*$')
 PHONE_NO_DETECTION_RE = re.compile(
     r'\s*([+(\s]*[0-9][0-9()\s-]+[0-9])(?=$|[\s,+(]+[0-9])', re.I)
 
+# Support for prefix: (string followed by colon) infront of phone no
+PHONE_NO_WPREFIX_DETECTION_RE = re.compile(
+    r'\s*((?:[a-z]+:)?[+(\s]*[0-9][0-9()\s-]+[0-9])'
+    r'(?=$|(?:[a-z]+:)?[\s,+(]+[0-9])', re.I)
+
 # A simple verification check to make sure the content specified
 # rougly conforms to a ham radio call sign before we parse it further
 IS_CALL_SIGN = re.compile(
@@ -939,7 +946,7 @@ def parse_bool(arg, default=False):
     return bool(arg)
 
 
-def parse_phone_no(*args, store_unparseable=True, **kwargs):
+def parse_phone_no(*args, store_unparseable=True, prefix=False, **kwargs):
     """
     Takes a string containing phone numbers separated by comma's and/or spaces
     and returns a list.
@@ -948,7 +955,8 @@ def parse_phone_no(*args, store_unparseable=True, **kwargs):
     result = []
     for arg in args:
         if isinstance(arg, str) and arg:
-            _result = PHONE_NO_DETECTION_RE.findall(arg)
+            _result = (PHONE_NO_DETECTION_RE if not prefix
+                       else PHONE_NO_WPREFIX_DETECTION_RE).findall(arg)
             if _result:
                 result += _result
 
@@ -966,7 +974,7 @@ def parse_phone_no(*args, store_unparseable=True, **kwargs):
         elif isinstance(arg, (set, list, tuple)):
             # Use recursion to handle the list of phone numbers
             result += parse_phone_no(
-                *arg, store_unparseable=store_unparseable)
+                *arg, store_unparseable=store_unparseable, prefix=prefix)
 
     return result
 
@@ -1523,7 +1531,7 @@ def environ(*remove, **update):
             locale.setlocale(locale.LC_ALL, loc_orig)
 
         except locale.Error:
-            # Thrown in py3.6
+            # Handle this case
             pass
 
 
@@ -1594,3 +1602,35 @@ def dict_full_update(dict1, dict2):
 
     _merge(dict1, dict2)
     return
+
+
+def decode_b64_dict(di: dict) -> dict:
+    di = copy.deepcopy(di)
+    for k, v in di.items():
+        if not isinstance(v, str) or not v.startswith("b64:"):
+            continue
+        try:
+            parsed_v = base64.b64decode(v[4:])
+            parsed_v = json.loads(parsed_v)
+        except Exception:
+            parsed_v = v
+        di[k] = parsed_v
+    return di
+
+
+def encode_b64_dict(
+        di: dict
+) -> typing.Tuple[dict, bool]:
+    di = copy.deepcopy(di)
+    needs_decoding = False
+    for k, v in di.items():
+        if isinstance(v, str):
+            continue
+        try:
+            encoded = base64.urlsafe_b64encode(json.dumps(v).encode())
+            encoded = "b64:{}".format(encoded.decode())
+            needs_decoding = True
+        except Exception:
+            encoded = str(v)
+        di[k] = encoded
+    return di, needs_decoding
