@@ -30,10 +30,11 @@ import sys
 import os
 
 import pytest
+import mimetypes
 
-from apprise.manager_plugins import NotificationManager
-from apprise.manager_config import ConfigurationManager
-from apprise.manager_attachment import AttachmentManager
+from apprise import NotificationManager
+from apprise import ConfigurationManager
+from apprise import AttachmentManager
 
 sys.path.append(os.path.join(os.path.dirname(__file__), 'helpers'))
 
@@ -45,6 +46,16 @@ C_MGR = ConfigurationManager()
 A_MGR = AttachmentManager()
 
 
+@pytest.fixture(scope="function", autouse=True)
+def mimetypes_always_available():
+    """
+    A pytest session fixture which ensures mimetypes is set correctly
+    pointing to our temporary mime.types file
+    """
+    files = (os.path.join(os.path.dirname(__file__), 'var', 'mime.types'), )
+    mimetypes.init(files=files)
+
+
 @pytest.fixture(scope="function", autouse=True)
 def no_throttling_everywhere(session_mocker):
     """
