@@ -51,7 +51,7 @@ from apprise import PrivacyMode
 from apprise.locale import LazyTranslation
 from apprise.locale import gettext_lazy as _
 
-from apprise.manager_plugins import NotificationManager
+from apprise import NotificationManager
 from apprise.utils import parse_list
 from helpers import OuterEventLoop
 import inspect
@@ -957,6 +957,18 @@ def test_apprise_asset(tmpdir):
     # None is the default
     assert a.color(NotifyType.INFO) == '#3AA3E3'
 
+    # Invalid Type
+    with pytest.raises(ValueError):
+        # The exception we expect since dict is not supported
+        a.color(NotifyType.INFO, dict)
+
+    # Test our ASCII mappings
+    assert a.ascii('invalid') == '[?]'
+    assert a.ascii(NotifyType.INFO) == '[i]'
+    assert a.ascii(NotifyType.SUCCESS) == '[+]'
+    assert a.ascii(NotifyType.WARNING) == '[~]'
+    assert a.ascii(NotifyType.FAILURE) == '[!]'
+
     # Invalid Type
     with pytest.raises(ValueError):
         # The exception we expect since dict is not supported
