@@ -36,7 +36,7 @@ from os.path import dirname
 from os.path import getsize
 from apprise.attachment.http import AttachHTTP
 from apprise import Apprise, AppriseAttachment
-from apprise.manager_plugins import NotificationManager
+from apprise import NotificationManager
 from apprise.plugins import NotifyBase
 from apprise.common import ContentLocation
 
@@ -229,7 +229,7 @@ def test_attach_http(mock_get, mock_post):
     attachment = AttachHTTP(**results)
     assert isinstance(attachment.url(), str) is True
     # both mime and name over-ridden
-    assert re.search(r'[?&]mime=image%2Fjpeg', attachment.url())
+    assert re.search(r'[?&]mime=image/jpeg', attachment.url())
     assert re.search(r'[?&]name=usethis.jpg', attachment.url())
     # No Content-Disposition; so we use filename from path
     assert attachment.name == 'usethis.jpg'
