@@ -34,7 +34,7 @@ import requests
 from apprise.common import ConfigFormat
 from apprise.config.http import ConfigHTTP
 from apprise.plugins import NotifyBase
-from apprise.manager_plugins import NotificationManager
+from apprise import NotificationManager
 
 # Disable logging for a cleaner testing output
 import logging
