@@ -49,7 +49,7 @@ if 'dbus' not in sys.modules:
 
 
 from dbus import DBusException  # noqa E402
-from apprise.plugins.NotifyDBus import DBusUrgency, NotifyDBus  # noqa E402
+from apprise.plugins.dbus import DBusUrgency, NotifyDBus  # noqa E402
 
 
 def setup_glib_environment():
@@ -114,7 +114,7 @@ def setup_glib_environment():
 
     # When patching something which has a side effect on the module-level code
     # of a plugin, make sure to reload it.
-    reload_plugin('NotifyDBus')
+    reload_plugin('dbus')
 
 
 @pytest.fixture
@@ -153,20 +153,20 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
 
     # Create our instance (identify all supported types)
     obj = apprise.Apprise.instantiate('dbus://', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('dbus://_/')
     obj = apprise.Apprise.instantiate('kde://', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('kde://_/')
     obj = apprise.Apprise.instantiate('qt://', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('qt://_/')
     obj = apprise.Apprise.instantiate('glib://', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('glib://_/')
     obj.duration = 0
 
@@ -189,8 +189,8 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
     # Test our arguments through the instantiate call
     obj = apprise.Apprise.instantiate(
         'dbus://_/?image=True', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('dbus://_/')
     assert re.search('image=yes', obj.url())
 
@@ -200,8 +200,8 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?image=False', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.url().startswith('dbus://_/')
     assert re.search('image=no', obj.url())
 
@@ -212,24 +212,24 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
     # Test priority (alias to urgency) handling
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=invalid', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=high', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?priority=2', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -237,32 +237,32 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
     # Test urgency handling
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=invalid', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=high', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=2', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'dbus://_/?urgency=', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -270,8 +270,8 @@ def test_plugin_dbus_general_success(mocker, dbus_glib_environment):
     # Test x/y
     obj = apprise.Apprise.instantiate(
         'dbus://_/?x=5&y=5', suppress_exceptions=False)
-    assert isinstance(obj, NotifyDBus) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyDBus)
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -415,7 +415,7 @@ def test_plugin_dbus_gi_missing(dbus_glib_environment):
 
     # When patching something which has a side effect on the module-level code
     # of a plugin, make sure to reload it.
-    reload_plugin('NotifyDBus')
+    reload_plugin('dbus')
 
     # Create the instance.
     obj = apprise.Apprise.instantiate('glib://', suppress_exceptions=False)
@@ -442,7 +442,7 @@ def test_plugin_dbus_gi_require_version_error(dbus_glib_environment):
 
     # When patching something which has a side effect on the module-level code
     # of a plugin, make sure to reload it.
-    reload_plugin('NotifyDBus')
+    reload_plugin('dbus')
 
     # Create instance.
     obj = apprise.Apprise.instantiate('glib://', suppress_exceptions=False)
@@ -469,7 +469,7 @@ def test_plugin_dbus_module_croaks(mocker, dbus_glib_environment):
 
     # When patching something which has a side effect on the module-level code
     # of a plugin, make sure to reload it.
-    reload_plugin('NotifyDBus')
+    reload_plugin('dbus')
 
     # Verify plugin is not available.
     obj = apprise.Apprise.instantiate('glib://', suppress_exceptions=False)
