@@ -30,7 +30,7 @@ from unittest import mock
 
 import requests
 from apprise import Apprise
-from apprise.plugins.NotifyPushDeer import NotifyPushDeer
+from apprise.plugins.pushdeer import NotifyPushDeer
 from helpers import AppriseURLTester
 
 # Disable logging for a cleaner testing output
@@ -110,8 +110,8 @@ def test_plugin_pushdeer_general(mock_post):
 
     # Variation Initializations
     obj = Apprise.instantiate('pushdeer://localhost/pushKey')
-    assert isinstance(obj, NotifyPushDeer) is True
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj, NotifyPushDeer)
+    assert isinstance(obj.url(), str)
 
     # Send Notification
     assert obj.send(body="test") is True
