@@ -109,7 +109,7 @@ def test_plugin_windows_mocked():
     obj.duration = 0
 
     # Test URL functionality
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
 
     # Check that it found our mocked environments
     assert obj.enabled is True
@@ -125,7 +125,7 @@ def test_plugin_windows_mocked():
     obj = apprise.Apprise.instantiate(
         'windows://_/?image=True', suppress_exceptions=False)
     obj.duration = 0
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -133,14 +133,14 @@ def test_plugin_windows_mocked():
     obj = apprise.Apprise.instantiate(
         'windows://_/?image=False', suppress_exceptions=False)
     obj.duration = 0
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'windows://_/?duration=1', suppress_exceptions=False)
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     # loads okay
     assert obj.duration == 1
     assert obj.notify(
@@ -211,7 +211,7 @@ def test_plugin_windows_native(mock_loadimage,
     obj.duration = 0
 
     # Test URL functionality
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
 
     # Check that it found our mocked environments
     assert obj.enabled is True
@@ -227,7 +227,7 @@ def test_plugin_windows_native(mock_loadimage,
     obj = apprise.Apprise.instantiate(
         'windows://_/?image=True', suppress_exceptions=False)
     obj.duration = 0
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
@@ -235,14 +235,14 @@ def test_plugin_windows_native(mock_loadimage,
     obj = apprise.Apprise.instantiate(
         'windows://_/?image=False', suppress_exceptions=False)
     obj.duration = 0
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
 
     obj = apprise.Apprise.instantiate(
         'windows://_/?duration=1', suppress_exceptions=False)
-    assert isinstance(obj.url(), str) is True
+    assert isinstance(obj.url(), str)
     assert obj.notify(
         title='title', body='body',
         notify_type=apprise.NotifyType.INFO) is True
